@@ -15,8 +15,13 @@ try:
     import readline
 except ImportError:
     import pyreadline as readline
+
+try:
+    prompt = raw_input
+except NameError:
+    prompt = input
     
-STAR_PILOT_HOME = os.path.join(os.path.expanduser("~"), ".starpilot")
+STAR_PILOT_HOME = os.path.join(os.path.expanduser("~"), ".mystarspilot")
 
 
 def main():
@@ -33,6 +38,8 @@ def main():
         help="create(first time) or update the local stars index")
     parser.add_argument("-r", "--reindex", action="store_true", 
         help="re-create the local stars index")
+    parser.add_argument("-a", "--alfred", action="store_true", 
+        help="format search result as Alfred XML")
     parser.add_argument('-v', '--version', action='version', 
         version='%(prog)s ' + __version__)
     
@@ -41,7 +48,7 @@ def main():
     if args.update or args.reindex:
         
         try:
-            user = raw_input('GitHub username: ')
+            user = prompt('GitHub username: ')
         except KeyboardInterrupt:
             user = getuser()
         else:
@@ -53,15 +60,38 @@ def main():
         if not password:
             print(Fore.RED + "password is required.")
             sys.exit(1)
-            
-        g = login(user, password)
+
+        def gh2f():
+            code = ''
+            while not code:
+                code = prompt('Enter 2FA code: ')
+            return code
+        g = login(user, password, two_factor_callback=gh2f)
         
         mode = 't' if args.reindex else 'w'
+        
         with StarredDB(STAR_PILOT_HOME, mode) as db:
+            repo_list = []
+            
             for repo in g.iter_starred():
-                print(repo.full_name)
-                db.update(repo)
-                
+                if db.get_latest_repo_full_name() == repo.full_name:
+                    break
+                print(Fore.BLUE + repo.full_name + Fore.RESET)
+                repo_list.append({
+                    'full_name': repo.full_name,
+                    'name': repo.name,
+                    'url': repo.html_url,
+                    'language': repo.language,
+                    'description': repo.description,
+                })
+            if repo_list:
+                print(Fore.GREEN + 'Saving repo data...')
+                db.update(repo_list)
+                print(Fore.RED + 'Done.' + Fore.RESET)   
+            else:
+                print(Fore.RED + 'No new stars found.' + Fore.RESET)
+            
+             
         sys.exit(0)
        
     if not args.keywords and not args.language:
@@ -71,4 +101,5 @@ def main():
     with StarredDB(STAR_PILOT_HOME, mode='r') as db:
         search_result = db.search(args.language, args.keywords)
     
-    SearchResultView().print_search_result(search_result, args.keywords)
+    SearchResultView().print_search_result(
+        search_result, args.keywords, alfred_format=args.alfred)
